# eric7.PipInterface.PipFileSelectionDialog

Module implementing a dialog to enter a file to be processed.

### Global Attributes

None

### Classes

PipFileSelectionDialog | Class implementing a dialog to enter a file to be processed.

### Functions

None

## PipFileSelectionDialog

Class implementing a dialog to enter a file to be processed.

### Derived from

QDialog, Ui_PipFileSelectionDialog

### Class Attributes

None

### Class Methods

None

### Methods

PipFileSelectionDialog | Constructor
getData | Public method to get the entered data.
on_filePicker_textChanged | Private slot to handle entering the name of a file.

### Static Methods

None

#### PipFileSelectionDialog (Constructor)

PipFileSelectionDialog(mode, install=True, parent=None)

Constructor

mode (str)
  mode of the dialog
install (bool)
  flag indicating an install action
parent (QWidget)
  reference to the parent widget

#### PipFileSelectionDialog.getData

getData()

Public method to get the entered data.

Return:
  tuple with the name of the selected file and a flag indicating to install to the user install directory

Return Type:
  tuple of (str, bool)

#### PipFileSelectionDialog.on_filePicker_textChanged

on_filePicker_textChanged(txt)

Private slot to handle entering the name of a file.

txt (str)
  name of the file

Up